==> atlcli-0.1.5.tar.gz: atlcli-0.1.5/README.md <==
# Altassian CLI
## Introduction
Altassian CLI is a Atlassian product CLI that allows you to create release notes, get infos about the repositories and repositories.
## Requirements
* Python 3.+
* Virtualenv
* PIP 3+

For ubuntu users:
```
$ sudo apt install python3 python3-pip
```
For other platforms
```
pip install virtualenv
```

## Project setup

In order to run the project you will first need to create a Virtual environment in python by running the following command.

```
pip install virtualenv
mkdir venv
python3 -m virtualenv ./venv
cd venv/bin
source activate
```

## Installing and adding pip dependencies
### Installing dependencies

After creating virtualenv you will need to install the requirements for the project. Go back to the root of the project and run the following command.

```
pip install -r requirements.txt
```
### Debug
```
pip install debugpy
python -m debugpy --listen 5678 cli/app.py
```

### Features
* Note de livraison qui affiche les etapes de livraison (comme les notes de livraison mpm)
* Changelog
* Conversion de wiki markup a storage format et ajout des checklist manquante

### Addding pip dependencies
After adding a new module to the project you will need to update the requirements.txt file in order for it to have the new module. You cand do this by running the following command.

```
pip freeze > requirements.txt
```
## Troubleshoot
```
Add --trusted-host files.pythonhosted.org to pip if you have issues with cert validation if you are behind a proxy.
```

## Doc
https://pypi.org/project/atlassian-python-api/
https://click.palletsprojects.com/en/7.x/
https://confluence.atlassian.com/doc/macros-139387.html
https://confluence.atlassian.com/doc/confluence-wiki-markup-251003035.html

==> atlcli-0.1.8.tar.gz: atlcli-0.1.8/README.md <==
# Altassian CLI
## Introduction
Altassian CLI is a Atlassian product CLI that allows you to create release notes, get infos about the repositories and repositories.

## Requirements
* Python 3.+
* Virtualenv
* PIP 3+

## Project setup

In order to run the project you will first need to create a Virtual environment in python by running the following command.

```
pip install virtualenv
mkdir venv
python3 -m virtualenv ./venv
cd venv/bin
source activate
pip install -r requirements.txt
```

## Installing locally
```
pip install . # While in root of project
```

## Concourse
```yaml
- task: generate release note
    config:
      platform: linux
      image_resource:
        type: docker-image
        source:
          repository: <repository link here>
      run:
        path: /bin/sh
        args:
          - -c
          - |            
            atlcli --help

```

## Usage
A guide for the tool can be found on the [Usage](./doc/Usage.md) page.

## Features
* Note de livraison qui affiche les etapes de livraison (comme les notes de livraison mpm)
* Changelog
* Conversion de wiki markup a storage format et ajout des checklist manquante


### Addding pip dependencies
After adding a new module to the project you will need to update the requirements.txt file in order for it to have the new module. You cand do this by running the following command.

```
pip freeze > requirements.txt
```
## Troubleshoot

Add trusted-host files.pythonhosted.org to pip if you have issues with cert validation if you are behind a proxy.
```
pip config set global.trusted-host "pypi.org files.pythonhosted.org pypi.python.org"
```
## Doc
https://pypi.org/project/atlassian-python-api/
https://click.palletsprojects.com/en/7.x/
https://confluence.atlassian.com/doc/macros-139387.html
https://confluence.atlassian.com/doc/confluence-wiki-markup-251003035.html
